==> zio-aws-codebuild_3-5.17.155.2-sources.jar: zio/aws/codebuild/model/StartBuildResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class StartBuildResponse(
    build: Option[zio.aws.codebuild.model.Build] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.StartBuildResponse = {
    import StartBuildResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.StartBuildResponse
      .builder()
      .optionallyWith(build.map(value => value.buildAwsValue()))(_.build)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.StartBuildResponse.ReadOnly =
    zio.aws.codebuild.model.StartBuildResponse.wrap(buildAwsValue())
}
object StartBuildResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.StartBuildResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.StartBuildResponse =
      zio.aws.codebuild.model
        .StartBuildResponse(build.map(value => value.asEditable))
    def build: Option[zio.aws.codebuild.model.Build.ReadOnly]
    def getBuild: ZIO[Any, AwsError, zio.aws.codebuild.model.Build.ReadOnly] =
      AwsError.unwrapOptionField("build", build)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.StartBuildResponse
  ) extends zio.aws.codebuild.model.StartBuildResponse.ReadOnly {
    override val build: Option[zio.aws.codebuild.model.Build.ReadOnly] = scala
      .Option(impl.build())
      .map(value => zio.aws.codebuild.model.Build.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.StartBuildResponse
  ): zio.aws.codebuild.model.StartBuildResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-codebuild_3-5.17.212.1-sources.jar: zio/aws/codebuild/model/StartBuildResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class StartBuildResponse(
    build: Optional[zio.aws.codebuild.model.Build] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.StartBuildResponse = {
    import StartBuildResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.StartBuildResponse
      .builder()
      .optionallyWith(build.map(value => value.buildAwsValue()))(_.build)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.StartBuildResponse.ReadOnly =
    zio.aws.codebuild.model.StartBuildResponse.wrap(buildAwsValue())
}
object StartBuildResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.StartBuildResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.StartBuildResponse =
      zio.aws.codebuild.model
        .StartBuildResponse(build.map(value => value.asEditable))
    def build: Optional[zio.aws.codebuild.model.Build.ReadOnly]
    def getBuild: ZIO[Any, AwsError, zio.aws.codebuild.model.Build.ReadOnly] =
      AwsError.unwrapOptionField("build", build)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.StartBuildResponse
  ) extends zio.aws.codebuild.model.StartBuildResponse.ReadOnly {
    override val build: Optional[zio.aws.codebuild.model.Build.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.build())
        .map(value => zio.aws.codebuild.model.Build.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.StartBuildResponse
  ): zio.aws.codebuild.model.StartBuildResponse.ReadOnly = new Wrapper(impl)
}
